#
# spec file for package libxfce4windowing
#
# Copyright (c) 2024 SUSE LLC

# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define api        0
%define major      0
%define libname    libxfce4windowing-%{api}-%{major}
%define libnameui  libxfce4windowingui-%{api}-%{major}
%define girname    typelib-1_0-Libxfce4windowing-%{api}_%{major}
%define girnameui  typelib-1_0-Libxfce4windowingui-%{api}_%{major}
%define devname    %{name}-devel
%define docname    %{devname}-doc

Name:           libxfce4windowing
Summary:        Windowing concept abstraction library for X11 and Wayland
Version:        4.20.0
Release:        1.1
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://gitlab.xfce.org/xfce/libxfce4windowing
Source0:        https://archive.xfce.org/src/xfce/libxfce4windowing/4.20/libxfce4windowing-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE 0001-relax-x11-version.patch -- Allow build for Leap with its ancient but sufficient X11 packages.
Patch1:         0001-relax-x11-version.patch
BuildRequires:  automake
BuildRequires:  gettext >= 0.19.8
BuildRequires:  meson
BuildRequires:  xfce4-dev-tools >= 4.19.3
BuildRequires:  pkgconfig(libdisplay-info) >= 0.1.1
BuildRequires:  pkgconfig(gdk-3.0) >= 3.24.10
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.42.8
BuildRequires:  pkgconfig(gdk-wayland-3.0) >= 3.24.10
BuildRequires:  pkgconfig(gdk-x11-3.0) >= 3.24.10
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.72.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.10
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.14
BuildRequires:  pkgconfig(wayland-client) >= 1.20
BuildRequires:  pkgconfig(wayland-protocols) >= 1.25
BuildRequires:  pkgconfig(wayland-scanner) >= 1.20
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(x11) >= 1.6.5
BuildRequires:  pkgconfig(xrandr) >= 1.5.0

%description
Libxfce4windowing is an abstraction library that attempts to present windowing
concepts (screens, toplevel windows, workspaces, etc.) in a
windowing-system-independent manner.

Currently, X11 is fully supported, via libwnck. Wayland is partially supported,
through various Wayland protocol extensions. However, the full range of
operations available on X11 is not available on Wayland, due to missing
features in these protocol extensions.

%package -n %{libname}
Summary:        X11/Wayland windowing utility library for Xfce
Group:          System/Libraries
# Make lang package installable
Provides:       %{name} = %{version}
Recommends:     %{name}-lang = %{version}

%description -n %{libname}
Libxfce4windowing is an abstraction library that attempts to present windowing
concepts (screens, toplevel windows, workspaces, etc.) in a
windowing-system-independent manner.

%package -n %{libnameui}
Summary:        X11/Wayland windowing utility library for Xfce - extra widgets
Group:          System/Libraries

%description -n %{libnameui}
Libxfce4windowingui is a UI widget utility library that makes use of
libxfce4windowing primitives.

%package -n %{girname}
Summary:        GObject Introspection interface description for Libxfce4windowing
Group:          System/Libraries

%description -n %{girname}
GObject Introspection interface description for Libxfce4windowing.

%package -n %{girnameui}
Summary:        GObject Introspection interface description for Libxfce4windowingui
Group:          System/Libraries

%description -n %{girnameui}
GObject Introspection interface description for Libxfce4windowingui.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       %{libnameui} = %{version}
Requires:       %{girname} = %{version}
Requires:       %{girnameui} = %{version}

%description -n %{devname}
Libxfce4windowing is an abstraction library that attempts to present windowing
concepts (screens, toplevel windows, workspaces, etc.) in a
windowing-system-independent manner.

Currently, X11 is fully supported, via libwnck. Wayland is partially supported,
through various Wayland protocol extensions. However, the full range of
operations available on X11 is not available on Wayland, due to missing
features in these protocol extensions.

%package -n %{docname}
Summary:       Documentation for libxfce4windowing
Group:         Documentation/HTML
BuildArch:     noarch
Supplements:   (%{devname} and patterns-base-documentation)

%description -n %{docname}
Provides documentation for libxfce4windowing,
an abstraction library that attempts to present windowing
concepts (screens, toplevel windows, workspaces, etc.) in a
windowing-system-independent manner.

%lang_package

%prep
%autosetup -p1
aclocal
automake

%build
%configure \
	--disable-static
    
%make_build

%install
%make_install
find %{buildroot} -name "*.la" -print -delete

%find_lang %{name} %{?no_lang_C}

%ldconfig_scriptlets -n %{libname}
%ldconfig_scriptlets -n %{libnameui}

%files -n %{libname}
%license COPYING
%{_libdir}/libxfce4windowing-%{api}.so.%{major}{,.*}

%files -n %{libnameui}
%license COPYING
%{_libdir}/libxfce4windowingui-%{api}.so.%{major}{,.*}

%files -n %{girname}
%license COPYING
%{_libdir}/girepository-1.0/Libxfce4windowing-%{api}.%{major}.typelib

%files -n %{girnameui}
%license COPYING
%{_libdir}/girepository-1.0/Libxfce4windowingui-%{api}.%{major}.typelib

%files -n %{devname}
%dir %{_includedir}/xfce4/
%{_includedir}/xfce4/libxfce4windowing{,ui}/
%{_libdir}/libxfce4windowing{,ui}-%{api}.so
%{_libdir}/pkgconfig/libxfce4windowing{,ui}-%{api}.pc
%{_libdir}/pkgconfig/libxfce4windowing-x11-%{api}.pc
%{_datadir}/gir-1.0/Libxfce4windowing-%{api}.%{major}.gir
%{_datadir}/gir-1.0/Libxfce4windowingui-%{api}.%{major}.gir

%files -n %{docname}
%doc NEWS README*
%{_datadir}/gtk-doc/html/libxfce4windowingui
%{_datadir}/gtk-doc/html/libxfce4windowing

%files lang -f %{name}.lang

%changelog
* Sun Dec 15 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.0
  * Translation Updates
- Refresh 0001-relax-x11-version.patch
* Sun Dec  1 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.10 [development release]
  * I18n: Update po/LINGUAS list
  * Fix XfwMonitor leak in steal_monitor_by_connector
  * Translation Updates
- Refresh 0001-relax-x11-version.patch
* Sat Nov  2 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.9 [development release]
  * Fix leak of seats GList
- Add 0001-relax-x11-version.patch to allow build for Leap with its
  ancient but sufficient X11 packages.
  Regenerate the various autoconf/automake files.
* Wed Oct 23 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.8 [development release]
  * Clean up xsettings client & work around GDK swallowing events
  * Remove private sources from the public sources list
* Wed Oct  9 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.7 [development release]
  * Fix missing parent instance in XfwSeatWayland
  * Add XfwWindowListMenu widget
  * Remove the "(constructor)" annotation on xfw_screen_get_default()
  * Fix crash on workspace add/remove after XfwWindowActionMenu destroyed
  * Make XfwWindowAction menu struct private
* Mon Oct  7 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.6 [development release]
  NB
  NB: There is an API/ABI break in this release.
  NB: The xfw_window_activate() function now takes four arguments rather than
  NB: the previous three. The second argument is now a XfwSeat instance (or NULL).
  NB
  * Actually export xfw_screen_get_seats from the library
  * Add XfwSeat abstraction
  * build: Adjust Wayland requirements for Xfce 4.20
* Thu Oct  3 2024 Manfred Hollstein <manfred.h@gmx.net>
- Add BuildRequires: meson
- Update to version 4.19.5 [development release]
  * Add more compiler flags to the meson build
  * Use physical geometry when comparing X11 window geometry to monitor
  * build: Bump requirements for Xfce 4.20
  * Include meson build files in autotools dist tarball
  * Set up GNU symbol visibility
  * Ditch maintainer mode
  * Suppress spurious uninitialized var warning
  * Make window listener struct static
  * Update meson build
  * Bump C std from gnu99 to gnu11
  * meson: fix missing checks for x11 and wayland feature detection
  * Fix physical monitor height not getting set on X11
  * Ensure private symbols don't end up in the introspection file
  * autotools: don't build tests by default
  * Print monitor ID in xfw-enum-monitors test app
  * Try to make monitor IDs stable between X11 and Wayland
  * Move xrandr event base into XfwMonitorManagerX11
  * Fetch X11 scale factor from XSETTINGS, not GDK
  * Fix monitor workarea setting when monitors appear
- Update to version 4.19.4 [development release]
  * Add tests/Makefile.am
  * x11: refresh monitors in an idle function
  * I18n: Update po/LINGUAS list
  * Add a couple small test programs
  * Defer binding to the toplevel manager until after we have the outputs
  * Add debug logging to toplevel output_enter/leave
  * Add debugging when finalizing output properties
  * Add a few more display synchronization points in the wayland code
  * Reset XfwMonitorWayland output_done/xdg_output_done count on finalize
  * Add XfwMonitor:fractional-scale
  * Add primary monitor fallback guessing to X11 too
  * Remove extra wl_registry for the wayland monitor management
  * Remove extra wl_registry for the wayland workspace manager
  * Fix missing wl_output & xdg_output assignment in XfwMonitorWayland
  * Add workarea info and tracking to XfwMonitor
  * Use XfwMonitor instead of GdkMonitor throughout
  * Add XfwScreen::monitor-added and XfwScreen::monitor-removed
  * Fix 'Since' doc tag typos
  * Don't g_warning() if xrandr returns no monitors
  * Add xfw_monitor_get_gdk_monitor()
  * Fix bad doc comment for XfwMonitor:is-primary
  * Add primary monitor concept to XfwMonitor
  * Use system-relative include paths in public headers
  * Fix bad property name (from a stray search-and-replace)
  * Move monitors list into XfwScreen
  * Make XfwScreen an abstract class instead of an interface
  * wayland: Fix monitor ownership
  * XfwMonitor: add object properties
  * Add XfwMonitor
  * Apply .clang-format file
  * clang-format: Add file
  * build: Complete use of XDT_VERSION_INIT
  * Fix warnings about typedef redeclaration
  * use -no-undefined so that libtool consumes it
  * scan-build: Add false positive file
  * build: clang: Fix -Wcast-align
  * I18n: Update po/LINGUAS list
  * Revert "Add new CI builds to build without X11 and Wayland"
  * I18n: Update po/LINGUAS list
  * Don't toggle show-desktop whenever wnck tells us it changed
  * make sure bash is found non non-linux
  * Add meson build files
  * Add layout-row and layout-column properties to XfwWorkspace
  * Implement workspace layout row/column for Wayland
  * I18n: Update po/LINGUAS list
  * Translation Updates
* Tue Apr  2 2024 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.19.3
  * Update copyright year
  * Ensure workspace/group state is correct on X11 before emitting signals
  * Set initial workspace's group properly on X11
  * Add XfwClientType to doc sections
  * Add xfw_set_client_type() to doc sections
  * Add xfw_set_client_type()
  * Add an X11-specific header and xfw_window_get_xid()
  * Remove xfw_(window|application)_get_id()
  * build: Use AM_DISTCHECK_CONFIGURE_FLAGS
  * Expose class ids in XfwWindow and XfwApplication
  * Update ext-workspace protocol spec to current version
  * XfwWindowX11: Improve monitor list management
  * XfwWindowX11: Fix monitor management
  * build: Search for bind_textdomain_codeset in libintl too
  * build: Test if wlr-protocols dir is empty at configure time
  * Use system wlr-protocols defs if avail, fall back to submodule if not
  * Reduce verbosity
  * Add missing G_END_DECLS
  * I18n: Update po/LINGUAS list
  * window-wayland: Set app_id only if it changes
  * application: Fix window memory management (V2)
  * I18n: Update po/LINGUAS list
  * window-wayland: Ensure app always exists (Fixes #14)
  * Add monitor-added and monitor-removed signals to XfwWorkspaceWayland
  * Minor cleanup to wayland group monitor code
  * Remove unused code from XfwWorkspaceGroupWayland
  * Fix missing monitors-changed signal emission on x11/dummy
  * x11: use workspace number as ID
  * Use G_N_ELEMENTS()
  * XfwApplication: Fix window memory management
  * Translation Updates
* Wed Jan 31 2024 Manfred Hollstein <manfred.h@gmx.net>
- Add detailed versions for BuildRequires: based on configure.ac
* Wed Jan 31 2024 Callum Farmer <gmbr3@opensuse.org>
- Use 4.19.2 final tarball
- Re-format spec file
- Fix typelib package name (missing capitalisation)
- Split off -doc subpackage
- Change license to SPDX format
- Use %%ldconfig_scriptlets
- Remove unneeded deps which will be automatically found by RPM
* Sat Apr  8 2023 mantarimay@pm.me
- Update to version 4.19.1+git.53.ae5e6e9:
  * XfwScreenX11: Fix typo in property name when creating window
* Fri Apr  7 2023 mantarimay@pm.me
- Update to version 4.19.1+git.52.cb2e2d1:
  * I18n: Update translation pt_BR (100%%).
* Mon Apr  3 2023 mantarimay@pm.me
- Update to version 4.19.1+git.51.2603596:
  * I18n: Update translation fr (100%%).
* Sat Mar 18 2023 mantarimay@pm.me
- Update to version 4.19.1+git.50.0ab53e0:
  * I18n: Add new translation ro (57%%).
* Mon Mar 13 2023 mantarimay@pm.me
- Update to version 4.19.1+git.49.d1d464d:
  * I18n: Add new translation en_GB (100%%).
* Wed Mar  8 2023 mantarimay@pm.me
- Update to version 4.19.1+git.48.92088c6:
  * Use XDT_CHECK_PACKAGE_BINARY for wayland-scanner
  * Use XDT_CHECK_OPTIONAL_FEATURE
* Mon Mar  6 2023 mantarimay@pm.me
- Update to version 4.19.1+git.46.ca3773e:
  * I18n: Add new translation id (100%%).
* Sun Mar  5 2023 mantarimay@pm.me
- Update to version 4.19.1+git.45.4a9f397:
  * Use XDT_VERSION_INIT() and eliminate need for configure.ac.in
* Sat Mar  4 2023 mantarimay@pm.me
- Update to version 4.19.1+git.44.0120b2d:
  * Use $PKG_CONFIG and not pkg-config in configure.ac
* Wed Mar  1 2023 mantarimay@pm.me
- Update to version 4.19.1+git.43.89198a1:
  * autogen.sh: fix xfce4-dev-tools dependency version
* Sat Feb 25 2023 mantarimay@pm.me
- Update to version 4.19.1+git.42.d0245eb:
  * I18n: Add new translation hr (68%%).
* Thu Feb 23 2023 mantarimay@pm.me
- Update to version 4.19.1+git.41.6672a6b:
  * I18n: Update translation ko (100%%).
  * I18n: Update translation sv (100%%).
* Tue Feb 21 2023 mantarimay@pm.me
- Update to version 4.19.1+git.39.19987e5:
  * build: Get rid of IntlTool
  * Use bind_textdomain_codeset() if available
  * build: Fix autotools warning
* Sat Feb 18 2023 mantarimay@pm.me
- Update to version 4.19.1+git.36.539af2a:
  * Update bug report address
  * build: Fix "make dist" when disable wayland
  * configure: Fix X11's dependencies detection
* Sun Feb  5 2023 mantarimay@pm.me
- Update to version 4.19.1+git.33.59416bd:
  * I18n: Add new translation ie (100%%).
  * I18n: Add new translation uk (73%%).
* Sat Feb  4 2023 mantarimay@pm.me
- Update to version 4.19.1+git.31.8f72515:
  * I18n: Add new translation ru (100%%).
* Fri Feb  3 2023 mantarimay@pm.me
- Update to version 4.19.1+git.30.8e21015:
  * I18n: Add new translation oc (78%%).
* Thu Feb  2 2023 mantarimay@pm.me
- Update to version 4.19.1+git.29.9923ca4:
  * I18n: Add new translation en_CA (100%%).
* Tue Jan 31 2023 mantarimay@pm.me
- Update to version 4.19.1+git.28.3ab4c88:
  * I18n: Add new translation zh_TW (89%%).
  * I18n: Add new translation zh_CN (100%%).
  * I18n: Add new translation tr (100%%).
  * I18n: Add new translation sv (94%%).
  * I18n: Add new translation sr (100%%).
  * I18n: Add new translation sq (100%%).
  * I18n: Add new translation sl (100%%).
  * I18n: Add new translation pt_BR (100%%).
  * I18n: Add new translation pt (100%%).
  * I18n: Add new translation pl (100%%).
  * I18n: Add new translation nl (100%%).
  * I18n: Add new translation nb (100%%).
  * I18n: Add new translation lt (100%%).
  * I18n: Add new translation ko (89%%).
  * I18n: Add new translation ja (100%%).
  * I18n: Add new translation it (100%%).
  * I18n: Add new translation he (100%%).
  * I18n: Add new translation fr (100%%).
  * I18n: Add new translation fi (73%%).
  * I18n: Add new translation es (100%%).
  * I18n: Add new translation de (100%%).
  * I18n: Add new translation bg (100%%).
* Sat Jan 14 2023 mantarimay@pm.me
- Update to version 4.19.1+git.6.66ca431:
  * XfwWnckIcon: Silently return NULL if no X11 window can be found
  * Add new CI builds to build without X11 and Wayland
  * configure: error out if no windowing backend enabled
  * Add configure args to enable/disable X11/Wayland
  * Fix Wayland-only build
  * Back to development
  * Updates for release
  * Allow callers to determine if a returned icon is a fallback icon
  * Remove duplicate _get_icon() code
  * Return correct fallback icon for XfwWindowWayland
* Fri Jan 13 2023 mantarimay@pm.me
- Update to version 4.19.1+git.6.66ca431:
  * XfwWnckIcon: Silently return NULL if no X11 window can be found
  * Add new CI builds to build without X11 and Wayland
  * configure: error out if no windowing backend enabled
  * Add configure args to enable/disable X11/Wayland
  * Fix Wayland-only build
  * Back to development
  * Updates for release
  * Allow callers to determine if a returned icon is a fallback icon
  * Remove duplicate _get_icon() code
  * Return correct fallback icon for XfwWindowWayland
* Mon Jan  9 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package for openSUSE
